Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Common Dataplex Universal Catalog fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexSpec

Returns a new instance of GoogleCloudDatacatalogV1DataplexSpec.



903
904
905
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Fully qualified resource name of an asset in Dataplex Universal Catalog, to which the underlying data source (Cloud Storage bucket or BigQuery dataset) of the entity is attached. Corresponds to the JSON property asset

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 883

def asset
  @asset
end

#compression_formatString

Compression format of the data, e.g., zip, gzip etc. Corresponds to the JSON property compressionFormat

Returns:

  • (String)


888
889
890
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 888

def compression_format
  @compression_format
end

#data_formatGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchema

Native schema used by a resource represented as an entry. Used by query engines for deserializing and parsing source data. Corresponds to the JSON property dataFormat



894
895
896
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 894

def data_format
  @data_format
end

#project_idString

Project ID of the underlying Cloud Storage or BigQuery data. Note that this may not be the same project as the corresponding Dataplex Universal Catalog lake / zone / asset. Corresponds to the JSON property projectId

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 901

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



908
909
910
911
912
913
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 908

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @compression_format = args[:compression_format] if args.key?(:compression_format)
  @data_format = args[:data_format] if args.key?(:data_format)
  @project_id = args[:project_id] if args.key?(:project_id)
end