Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1Entry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Entry metadata. A Data Catalog entry represents another resource in Google Cloud Platform (such as a BigQuery dataset or a Pub/Sub topic) or outside of it. You can use the linked_resource field in the entry resource to refer to the original resource ID of the source system. An entry resource contains resource details, for example, its schema. Additionally, you can attach flexible metadata to an entry in the form of a Tag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1Entry

Returns a new instance of GoogleCloudDatacatalogV1Entry.



1208
1209
1210
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_date_sharded_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1BigQueryDateShardedSpec

Specification for a group of BigQuery tables with the [prefix]YYYYMMDD name pattern. For more information, see Introduction to partitioned tables. Corresponds to the JSON property bigqueryDateShardedSpec



1005
1006
1007
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1005

def bigquery_date_sharded_spec
  @bigquery_date_sharded_spec
end

#bigquery_table_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1BigQueryTableSpec

Describes a BigQuery table. Corresponds to the JSON property bigqueryTableSpec



1010
1011
1012
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1010

def bigquery_table_spec
  @bigquery_table_spec
end

#business_contextGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1BusinessContext

Business Context of the entry. Corresponds to the JSON property businessContext



1015
1016
1017
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1015

def business_context
  @business_context
end

#cloud_bigtable_system_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1CloudBigtableSystemSpec

Specification that applies to all entries that are part of CLOUD_BIGTABLE system (user_specified_type) Corresponds to the JSON property cloudBigtableSystemSpec



1021
1022
1023
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1021

def cloud_bigtable_system_spec
  @cloud_bigtable_system_spec
end

#data_sourceGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataSource

Physical location of an entry. Corresponds to the JSON property dataSource



1026
1027
1028
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1026

def data_source
  @data_source
end

#data_source_connection_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataSourceConnectionSpec

Specification that applies to a data source connection. Valid only for entries with the DATA_SOURCE_CONNECTION type. Only one of internal specs can be set at the time, and cannot be changed later. Corresponds to the JSON property dataSourceConnectionSpec



1033
1034
1035
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1033

def data_source_connection_spec
  @data_source_connection_spec
end

#database_table_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DatabaseTableSpec

Specification that applies to a table resource. Valid only for entries with the TABLE type. Corresponds to the JSON property databaseTableSpec



1039
1040
1041
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1039

def database_table_spec
  @database_table_spec
end

#dataset_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DatasetSpec

Specification that applies to a dataset. Valid only for entries with the DATASET type. Corresponds to the JSON property datasetSpec



1045
1046
1047
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1045

def dataset_spec
  @dataset_spec
end

#descriptionString

Entry description that can consist of several sentences or paragraphs that describe entry contents. The description must not contain Unicode non- characters as well as C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF). The maximum size is 2000 bytes when encoded in UTF-8. Default value is an empty string. Corresponds to the JSON property description

Returns:

  • (String)


1054
1055
1056
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1054

def description
  @description
end

#display_nameString

Display name of an entry. The maximum size is 500 bytes when encoded in UTF-8. Default value is an empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


1060
1061
1062
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1060

def display_name
  @display_name
end

#feature_online_store_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1FeatureOnlineStoreSpec

Detail description of the source information of a Vertex Feature Online Store. Corresponds to the JSON property featureOnlineStoreSpec



1065
1066
1067
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1065

def feature_online_store_spec
  @feature_online_store_spec
end

#fileset_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1FilesetSpec

Specification that applies to a fileset. Valid only for entries with the ' FILESET' type. Corresponds to the JSON property filesetSpec



1071
1072
1073
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1071

def fileset_spec
  @fileset_spec
end

#fully_qualified_nameString

Fully Qualified Name (FQN) of the resource. Set automatically for entries representing resources from synced systems. Settable only during creation, and read-only later. Can be used for search and lookup of the entries. Corresponds to the JSON property fullyQualifiedName

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1079

def fully_qualified_name
  @fully_qualified_name
end

#gcs_fileset_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GcsFilesetSpec

Describes a Cloud Storage fileset entry. Corresponds to the JSON property gcsFilesetSpec



1084
1085
1086
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1084

def gcs_fileset_spec
  @gcs_fileset_spec
end

#graph_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpec

Specification that applies to a graph. Corresponds to the JSON property graphSpec



1089
1090
1091
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1089

def graph_spec
  @graph_spec
end

#integrated_systemString

Output only. Indicates the entry's source system that Data Catalog integrates with, such as BigQuery, Pub/Sub, or Dataproc Metastore. Corresponds to the JSON property integratedSystem

Returns:

  • (String)


1095
1096
1097
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1095

def integrated_system
  @integrated_system
end

#labelsHash<String,String>

Cloud labels attached to the entry. In Data Catalog, you can create and modify labels attached only to custom entries. Synced entries have unmodifiable labels that come from the source system. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1102
1103
1104
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1102

def labels
  @labels
end

#linked_resourceString

The resource this metadata entry refers to. For Google Cloud Platform resources, linked_resource is the Full Resource Name. For example, the linked_resource for a table resource from BigQuery is: //bigquery.googleapis. com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID`Output only when the entry is one of the types in theEntryTypeenum. For entries with a user_specified_type`, this field is optional and defaults to an empty string. The resource string must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), periods (.), colons (:), slashes (/), dashes (-), and hashes (

). The maximum size is 200 bytes when encoded in UTF-8.

Corresponds to the JSON property linkedResource

Returns:

  • (String)


1116
1117
1118
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1116

def linked_resource
  @linked_resource
end

#looker_system_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1LookerSystemSpec

Specification that applies to entries that are part LOOKER system ( user_specified_type) Corresponds to the JSON property lookerSystemSpec



1122
1123
1124
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1122

def looker_system_spec
  @looker_system_spec
end

#model_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1ModelSpec

Specification that applies to a model. Valid only for entries with the MODEL type. Corresponds to the JSON property modelSpec



1128
1129
1130
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1128

def model_spec
  @model_spec
end

#nameString

Output only. Identifier. The resource name of an entry in URL format. Note: The entry itself and its child resources might not be stored in the location specified in its name. Corresponds to the JSON property name

Returns:

  • (String)


1135
1136
1137
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1135

def name
  @name
end

#personal_detailsGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PersonalDetails

Entry metadata relevant only to the user and private to them. Corresponds to the JSON property personalDetails



1140
1141
1142
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1140

def personal_details
  @personal_details
end

#routine_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1RoutineSpec

Specification that applies to a routine. Valid only for entries with the ROUTINE type. Corresponds to the JSON property routineSpec



1146
1147
1148
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1146

def routine_spec
  @routine_spec
end

#schemaGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1Schema

Represents a schema, for example, a BigQuery, GoogleSQL, or Avro schema. Corresponds to the JSON property schema



1151
1152
1153
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1151

def schema
  @schema
end

#service_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1ServiceSpec

Specification that applies to a Service resource. Valid only for entries with the SERVICE type. Corresponds to the JSON property serviceSpec



1157
1158
1159
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1157

def service_spec
  @service_spec
end

#source_system_timestampsGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1SystemTimestamps

Timestamps associated with this resource in a particular system. Corresponds to the JSON property sourceSystemTimestamps



1162
1163
1164
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1162

def source_system_timestamps
  @source_system_timestamps
end

#spanner_table_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1SpannerTableSpec

Specification of a Spanner table. Corresponds to the JSON property spannerTableSpec



1167
1168
1169
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1167

def spanner_table_spec
  @spanner_table_spec
end

#sql_database_system_specGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1SqlDatabaseSystemSpec

Specification that applies to entries that are part SQL_DATABASE system ( user_specified_type) Corresponds to the JSON property sqlDatabaseSystemSpec



1173
1174
1175
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1173

def sql_database_system_spec
  @sql_database_system_spec
end

#typeString

The type of the entry. For details, see EntryType. Corresponds to the JSON property type

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1178

def type
  @type
end

#usage_signalGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1UsageSignal

The set of all usage signals that Data Catalog stores. Note: Usually, these signals are updated daily. In rare cases, an update may fail but will be performed again on the next day. Corresponds to the JSON property usageSignal



1185
1186
1187
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1185

def usage_signal
  @usage_signal
end

#user_specified_systemString

Indicates the entry's source system that Data Catalog doesn't automatically integrate with. The user_specified_system string has the following limitations: * Is case insensitive. * Must begin with a letter or underscore. * Can only contain letters, numbers, and underscores. * Must be at least 1 character and at most 64 characters long. Corresponds to the JSON property userSpecifiedSystem

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1194

def user_specified_system
  @user_specified_system
end

#user_specified_typeString

Custom entry type that doesn't match any of the values allowed for input and listed in the EntryType enum. When creating an entry, first check the type values in the enum. If there are no appropriate types for the new entry, provide a custom value, for example, my_special_type. The user_specified_type string has the following limitations: * Is case insensitive. * Must begin with a letter or underscore. * Can only contain letters, numbers, and underscores. * Must be at least 1 character and at most 64 characters long. Corresponds to the JSON property userSpecifiedType

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1206

def user_specified_type
  @user_specified_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1213

def update!(**args)
  @bigquery_date_sharded_spec = args[:bigquery_date_sharded_spec] if args.key?(:bigquery_date_sharded_spec)
  @bigquery_table_spec = args[:bigquery_table_spec] if args.key?(:bigquery_table_spec)
  @business_context = args[:business_context] if args.key?(:business_context)
  @cloud_bigtable_system_spec = args[:cloud_bigtable_system_spec] if args.key?(:cloud_bigtable_system_spec)
  @data_source = args[:data_source] if args.key?(:data_source)
  @data_source_connection_spec = args[:data_source_connection_spec] if args.key?(:data_source_connection_spec)
  @database_table_spec = args[:database_table_spec] if args.key?(:database_table_spec)
  @dataset_spec = args[:dataset_spec] if args.key?(:dataset_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @feature_online_store_spec = args[:feature_online_store_spec] if args.key?(:feature_online_store_spec)
  @fileset_spec = args[:fileset_spec] if args.key?(:fileset_spec)
  @fully_qualified_name = args[:fully_qualified_name] if args.key?(:fully_qualified_name)
  @gcs_fileset_spec = args[:gcs_fileset_spec] if args.key?(:gcs_fileset_spec)
  @graph_spec = args[:graph_spec] if args.key?(:graph_spec)
  @integrated_system = args[:integrated_system] if args.key?(:integrated_system)
  @labels = args[:labels] if args.key?(:labels)
  @linked_resource = args[:linked_resource] if args.key?(:linked_resource)
  @looker_system_spec = args[:looker_system_spec] if args.key?(:looker_system_spec)
  @model_spec = args[:model_spec] if args.key?(:model_spec)
  @name = args[:name] if args.key?(:name)
  @personal_details = args[:personal_details] if args.key?(:personal_details)
  @routine_spec = args[:routine_spec] if args.key?(:routine_spec)
  @schema = args[:schema] if args.key?(:schema)
  @service_spec = args[:service_spec] if args.key?(:service_spec)
  @source_system_timestamps = args[:source_system_timestamps] if args.key?(:source_system_timestamps)
  @spanner_table_spec = args[:spanner_table_spec] if args.key?(:spanner_table_spec)
  @sql_database_system_spec = args[:sql_database_system_spec] if args.key?(:sql_database_system_spec)
  @type = args[:type] if args.key?(:type)
  @usage_signal = args[:usage_signal] if args.key?(:usage_signal)
  @user_specified_system = args[:user_specified_system] if args.key?(:user_specified_system)
  @user_specified_type = args[:user_specified_type] if args.key?(:user_specified_type)
end