Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1EntryOverview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Entry overview fields for rich text descriptions of entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1EntryOverview

Returns a new instance of GoogleCloudDatacatalogV1EntryOverview.



1261
1262
1263
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#overviewString

Entry overview with support for rich text. The overview must only contain Unicode characters, and should be formatted using HTML. The maximum length is 10 MiB as this value holds HTML descriptions including encoded images. The maximum length of the text without images is 100 KiB. Corresponds to the JSON property overview

Returns:

  • (String)


1259
1260
1261
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1259

def overview
  @overview
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1266
1267
1268
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1266

def update!(**args)
  @overview = args[:overview] if args.key?(:overview)
end