Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

A reference to a source or destination node in a graph edge.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference

Returns a new instance of GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference.



1511
1512
1513
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#edge_table_columnsArray<String>

Required. The referencing columns in the edge table. The size of edge_table_columns must be equal to the size of node_table_columns. Corresponds to the JSON property edgeTableColumns

Returns:

  • (Array<String>)


1497
1498
1499
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1497

def edge_table_columns
  @edge_table_columns
end

#node_aliasString

Required. The reference to the source/destination node of the edge. This name must be a valid alias of a node element in the same graph. Example, Person node can be a source node name of an edge element Person_to_Address. Corresponds to the JSON property nodeAlias

Returns:

  • (String)


1504
1505
1506
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1504

def node_alias
  @node_alias
end

#node_table_columnsArray<String>

Required. The referenced columns of the source node table. Corresponds to the JSON property nodeTableColumns

Returns:

  • (Array<String>)


1509
1510
1511
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1509

def node_table_columns
  @node_table_columns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1516
1517
1518
1519
1520
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1516

def update!(**args)
  @edge_table_columns = args[:edge_table_columns] if args.key?(:edge_table_columns)
  @node_alias = args[:node_alias] if args.key?(:node_alias)
  @node_table_columns = args[:node_table_columns] if args.key?(:node_table_columns)
end