Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1ImportEntriesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Metadata message for long-running operation returned by the ImportEntries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1ImportEntriesMetadata

Returns a new instance of GoogleCloudDatacatalogV1ImportEntriesMetadata.



1590
1591
1592
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::DatacatalogV1beta1::Status>

Partial errors that are encountered during the ImportEntries operation. There is no guarantee that all the encountered errors are reported. However, if no errors are reported, it means that no errors were encountered. Corresponds to the JSON property errors



1583
1584
1585
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1583

def errors
  @errors
end

#stateString

State of the import operation. Corresponds to the JSON property state

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1588

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1595
1596
1597
1598
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1595

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @state = args[:state] if args.key?(:state)
end