Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PersonalDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Entry metadata relevant only to the user and private to them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1PersonalDetails

Returns a new instance of GoogleCloudDatacatalogV1PersonalDetails.



1713
1714
1715
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#star_timeString

Set if the entry is starred; unset otherwise. Corresponds to the JSON property starTime

Returns:

  • (String)


1705
1706
1707
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1705

def star_time
  @star_time
end

#starredBoolean Also known as: starred?

True if the entry is starred by the user; false otherwise. Corresponds to the JSON property starred

Returns:

  • (Boolean)


1710
1711
1712
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1710

def starred
  @starred
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1718
1719
1720
1721
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1718

def update!(**args)
  @star_time = args[:star_time] if args.key?(:star_time)
  @starred = args[:starred] if args.key?(:starred)
end