Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchema
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
Native schema used by a resource represented as an entry. Used by query engines for deserializing and parsing source data.
Instance Attribute Summary collapse
-
#avro ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema
Schema in Avro JSON format.
-
#csv ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema
Marks a CSV-encoded data source.
-
#orc ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema
Marks an ORC-encoded data source.
-
#parquet ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema
Marks a Parquet-encoded data source.
-
#protobuf ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema
Schema in protocol buffer format.
-
#thrift ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema
Schema in Thrift format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1PhysicalSchema
constructor
A new instance of GoogleCloudDatacatalogV1PhysicalSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1PhysicalSchema
Returns a new instance of GoogleCloudDatacatalogV1PhysicalSchema.
1759 1760 1761 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avro ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema
Schema in Avro JSON format.
Corresponds to the JSON property avro
1732 1733 1734 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1732 def avro @avro end |
#csv ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema
Marks a CSV-encoded data source.
Corresponds to the JSON property csv
1737 1738 1739 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1737 def csv @csv end |
#orc ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema
Marks an ORC-encoded data source.
Corresponds to the JSON property orc
1742 1743 1744 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1742 def orc @orc end |
#parquet ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema
Marks a Parquet-encoded data source.
Corresponds to the JSON property parquet
1747 1748 1749 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1747 def parquet @parquet end |
#protobuf ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema
Schema in protocol buffer format.
Corresponds to the JSON property protobuf
1752 1753 1754 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1752 def protobuf @protobuf end |
#thrift ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema
Schema in Thrift format.
Corresponds to the JSON property thrift
1757 1758 1759 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1757 def thrift @thrift end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1764 1765 1766 1767 1768 1769 1770 1771 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1764 def update!(**args) @avro = args[:avro] if args.key?(:avro) @csv = args[:csv] if args.key?(:csv) @orc = args[:orc] if args.key?(:orc) @parquet = args[:parquet] if args.key?(:parquet) @protobuf = args[:protobuf] if args.key?(:protobuf) @thrift = args[:thrift] if args.key?(:thrift) end |