Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1SpannerTableSpecSpannerForeignKeyForeignKeyColumnMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Column mapping for a Spanner foreign key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1SpannerTableSpecSpannerForeignKeyForeignKeyColumnMapping

Returns a new instance of GoogleCloudDatacatalogV1SpannerTableSpecSpannerForeignKeyForeignKeyColumnMapping.



2127
2128
2129
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

Output only. The column in the current table that is part of the foreign key. Corresponds to the JSON property column

Returns:

  • (String)


2119
2120
2121
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2119

def column
  @column
end

#reference_columnString

Output only. The column in the referenced table that is part of the foreign key. Corresponds to the JSON property referenceColumn

Returns:

  • (String)


2125
2126
2127
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2125

def reference_column
  @reference_column
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2132
2133
2134
2135
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2132

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @reference_column = args[:reference_column] if args.key?(:reference_column)
end