Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1SystemTimestamps
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1SystemTimestamps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
Timestamps associated with this resource in a particular system.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Creation timestamp of the resource within the given system.
-
#expire_time ⇒ String
Output only.
-
#update_time ⇒ String
Timestamp of the last modification of the resource or its metadata within a given system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SystemTimestamps
constructor
A new instance of GoogleCloudDatacatalogV1SystemTimestamps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1SystemTimestamps
Returns a new instance of GoogleCloudDatacatalogV1SystemTimestamps.
2251 2252 2253 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Creation timestamp of the resource within the given system.
Corresponds to the JSON property createTime
2235 2236 2237 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2235 def create_time @create_time end |
#expire_time ⇒ String
Output only. Expiration timestamp of the resource within the given system.
Currently only applicable to BigQuery resources.
Corresponds to the JSON property expireTime
2241 2242 2243 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2241 def expire_time @expire_time end |
#update_time ⇒ String
Timestamp of the last modification of the resource or its metadata within a
given system. Note: Depending on the source system, not every modification
updates this timestamp. For example, BigQuery timestamps every metadata
modification but not data or permission changes.
Corresponds to the JSON property updateTime
2249 2250 2251 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2249 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2256 2257 2258 2259 2260 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2256 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @update_time = args[:update_time] if args.key?(:update_time) end |