Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1UsageSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

The set of all usage signals that Data Catalog stores. Note: Usually, these signals are updated daily. In rare cases, an update may fail but will be performed again on the next day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1UsageSignal

Returns a new instance of GoogleCloudDatacatalogV1UsageSignal.



2501
2502
2503
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_usage_within_time_rangeHash<String,Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1CommonUsageStats>

Common usage statistics over each of the predefined time ranges. Supported time ranges are "24H", "7D", "30D", "Lifetime". Corresponds to the JSON property commonUsageWithinTimeRange



2483
2484
2485
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2483

def common_usage_within_time_range
  @common_usage_within_time_range
end

#favorite_countFixnum

Favorite count in the source system. Corresponds to the JSON property favoriteCount

Returns:

  • (Fixnum)


2488
2489
2490
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2488

def favorite_count
  @favorite_count
end

#update_timeString

The end timestamp of the duration of usage statistics. Corresponds to the JSON property updateTime

Returns:

  • (String)


2493
2494
2495
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2493

def update_time
  @update_time
end

#usage_within_time_rangeHash<String,Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1UsageStats>

Output only. BigQuery usage statistics over each of the predefined time ranges. Supported time ranges are "24H", "7D", "30D". Corresponds to the JSON property usageWithinTimeRange



2499
2500
2501
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2499

def usage_within_time_range
  @usage_within_time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2506
2507
2508
2509
2510
2511
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2506

def update!(**args)
  @common_usage_within_time_range = args[:common_usage_within_time_range] if args.key?(:common_usage_within_time_range)
  @favorite_count = args[:favorite_count] if args.key?(:favorite_count)
  @update_time = args[:update_time] if args.key?(:update_time)
  @usage_within_time_range = args[:usage_within_time_range] if args.key?(:usage_within_time_range)
end