Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1UsageStats
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1UsageStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
Detailed statistics on the entry's usage. Usage statistics have the following limitations: - Only BigQuery tables have them. - They only include BigQuery query jobs. - They might be underestimated because wildcard table references are not yet counted. For more information, see Querying multiple tables using a wildcard table
Instance Attribute Summary collapse
-
#total_cancellations ⇒ Float
The number of cancelled attempts to use the underlying entry.
-
#total_completions ⇒ Float
The number of successful uses of the underlying entry.
-
#total_execution_time_for_completions_millis ⇒ Float
Total time spent only on successful uses, in milliseconds.
-
#total_failures ⇒ Float
The number of failed attempts to use the underlying entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1UsageStats
constructor
A new instance of GoogleCloudDatacatalogV1UsageStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1UsageStats
Returns a new instance of GoogleCloudDatacatalogV1UsageStats.
2543 2544 2545 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#total_cancellations ⇒ Float
The number of cancelled attempts to use the underlying entry.
Corresponds to the JSON property totalCancellations
2526 2527 2528 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2526 def total_cancellations @total_cancellations end |
#total_completions ⇒ Float
The number of successful uses of the underlying entry.
Corresponds to the JSON property totalCompletions
2531 2532 2533 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2531 def total_completions @total_completions end |
#total_execution_time_for_completions_millis ⇒ Float
Total time spent only on successful uses, in milliseconds.
Corresponds to the JSON property totalExecutionTimeForCompletionsMillis
2536 2537 2538 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2536 def total_execution_time_for_completions_millis @total_execution_time_for_completions_millis end |
#total_failures ⇒ Float
The number of failed attempts to use the underlying entry.
Corresponds to the JSON property totalFailures
2541 2542 2543 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2541 def total_failures @total_failures end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2548 2549 2550 2551 2552 2553 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2548 def update!(**args) @total_cancellations = args[:total_cancellations] if args.key?(:total_cancellations) @total_completions = args[:total_completions] if args.key?(:total_completions) @total_execution_time_for_completions_millis = args[:total_execution_time_for_completions_millis] if args.key?(:total_execution_time_for_completions_millis) @total_failures = args[:total_failures] if args.key?(:total_failures) end |