Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1VertexModelSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Specification for vertex model resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1VertexModelSpec

Returns a new instance of GoogleCloudDatacatalogV1VertexModelSpec.



2639
2640
2641
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_image_uriString

URI of the Docker image to be used as the custom container for serving predictions. Corresponds to the JSON property containerImageUri

Returns:

  • (String)


2616
2617
2618
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2616

def container_image_uri
  @container_image_uri
end

#version_aliasesArray<String>

User provided version aliases so that a model version can be referenced via alias Corresponds to the JSON property versionAliases

Returns:

  • (Array<String>)


2622
2623
2624
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2622

def version_aliases
  @version_aliases
end

#version_descriptionString

The description of this version. Corresponds to the JSON property versionDescription

Returns:

  • (String)


2627
2628
2629
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2627

def version_description
  @version_description
end

#version_idString

The version ID of the model. Corresponds to the JSON property versionId

Returns:

  • (String)


2632
2633
2634
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2632

def version_id
  @version_id
end

#vertex_model_source_infoGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1VertexModelSourceInfo

Detail description of the source information of a Vertex model. Corresponds to the JSON property vertexModelSourceInfo



2637
2638
2639
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2637

def vertex_model_source_info
  @vertex_model_source_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2644
2645
2646
2647
2648
2649
2650
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2644

def update!(**args)
  @container_image_uri = args[:container_image_uri] if args.key?(:container_image_uri)
  @version_aliases = args[:version_aliases] if args.key?(:version_aliases)
  @version_description = args[:version_description] if args.key?(:version_description)
  @version_id = args[:version_id] if args.key?(:version_id)
  @vertex_model_source_info = args[:vertex_model_source_info] if args.key?(:vertex_model_source_info)
end