Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1EntryGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

EntryGroup Metadata. An EntryGroup resource represents a logical grouping of zero or more Data Catalog Entry resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1EntryGroup

Returns a new instance of GoogleCloudDatacatalogV1beta1EntryGroup.



2943
2944
2945
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_catalog_timestampsGoogle::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SystemTimestamps

Timestamps about this resource according to a particular system. Corresponds to the JSON property dataCatalogTimestamps



2921
2922
2923
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2921

def data_catalog_timestamps
  @data_catalog_timestamps
end

#descriptionString

Entry group description, which can consist of several sentences or paragraphs that describe entry group contents. Default value is an empty string. Corresponds to the JSON property description

Returns:

  • (String)


2927
2928
2929
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2927

def description
  @description
end

#display_nameString

A short name to identify the entry group, for example, "analytics data - jan 2011". Default value is an empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


2933
2934
2935
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2933

def display_name
  @display_name
end

#nameString

Identifier. The resource name of the entry group in URL format. Example: * projects/project_id/locations/location/entryGroups/entry_group_id Note that this EntryGroup and its child resources may not actually be stored in the location in this name. Corresponds to the JSON property name

Returns:

  • (String)


2941
2942
2943
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2941

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2948
2949
2950
2951
2952
2953
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2948

def update!(**args)
  @data_catalog_timestamps = args[:data_catalog_timestamps] if args.key?(:data_catalog_timestamps)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
end