Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SearchCatalogResult
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SearchCatalogResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
A result that appears in the response of a search request. Each result captures details of one entry that matches the search.
Instance Attribute Summary collapse
-
#linked_resource ⇒ String
The full name of the cloud resource the entry belongs to.
-
#modify_time ⇒ String
Last-modified timestamp of the entry from the managing system.
-
#relative_resource_name ⇒ String
The relative resource name of the resource in URL format.
-
#search_result_subtype ⇒ String
Sub-type of the search result.
-
#search_result_type ⇒ String
Type of the search result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1SearchCatalogResult
constructor
A new instance of GoogleCloudDatacatalogV1beta1SearchCatalogResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1SearchCatalogResult
Returns a new instance of GoogleCloudDatacatalogV1beta1SearchCatalogResult.
3602 3603 3604 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#linked_resource ⇒ String
The full name of the cloud resource the entry belongs to. See: https://cloud.
google.com/apis/design/resource_names#full_resource_name. Example: * //
bigquery.googleapis.com/projects/projectId/datasets/datasetId/tables/tableId
Corresponds to the JSON property linkedResource
3574 3575 3576 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3574 def linked_resource @linked_resource end |
#modify_time ⇒ String
Last-modified timestamp of the entry from the managing system.
Corresponds to the JSON property modifyTime
3579 3580 3581 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3579 def modify_time @modify_time end |
#relative_resource_name ⇒ String
The relative resource name of the resource in URL format. Examples: *
projects/project_id/locations/location_id/entryGroups/entry_group_id/
entries/entry_id* `projects/`project_id`/tagTemplates/`tag_template_id
Corresponds to the JSON property relativeResourceName
3586 3587 3588 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3586 def relative_resource_name @relative_resource_name end |
#search_result_subtype ⇒ String
Sub-type of the search result. This is a dot-delimited description of the
resource's full type, and is the same as the value callers would provide in
the "type" search facet. Examples: entry.table, entry.dataStream,
tagTemplate.
Corresponds to the JSON property searchResultSubtype
3594 3595 3596 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3594 def search_result_subtype @search_result_subtype end |
#search_result_type ⇒ String
Type of the search result. This field can be used to determine which Get
method to call to fetch the full resource.
Corresponds to the JSON property searchResultType
3600 3601 3602 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3600 def search_result_type @search_result_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3607 3608 3609 3610 3611 3612 3613 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3607 def update!(**args) @linked_resource = args[:linked_resource] if args.key?(:linked_resource) @modify_time = args[:modify_time] if args.key?(:modify_time) @relative_resource_name = args[:relative_resource_name] if args.key?(:relative_resource_name) @search_result_subtype = args[:search_result_subtype] if args.key?(:search_result_subtype) @search_result_type = args[:search_result_type] if args.key?(:search_result_type) end |