Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SerializedTaxonomy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Message capturing a taxonomy and its policy tag hierarchy as a nested proto. Used for taxonomy import/export and mutation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1SerializedTaxonomy

Returns a new instance of GoogleCloudDatacatalogV1beta1SerializedTaxonomy.



3683
3684
3685
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activated_policy_typesArray<String>

A list of policy types that are activated for a taxonomy. Corresponds to the JSON property activatedPolicyTypes

Returns:

  • (Array<String>)


3664
3665
3666
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3664

def activated_policy_types
  @activated_policy_types
end

#descriptionString

Description of the serialized taxonomy. The length of the description is limited to 2000 bytes when encoded in UTF-8. If not set, defaults to an empty description. Corresponds to the JSON property description

Returns:

  • (String)


3671
3672
3673
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3671

def description
  @description
end

#display_nameString

Required. Display name of the taxonomy. Max 200 bytes when encoded in UTF-8. Corresponds to the JSON property displayName

Returns:

  • (String)


3676
3677
3678
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3676

def display_name
  @display_name
end

#policy_tagsArray<Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SerializedPolicyTag>

Top level policy tags associated with the taxonomy if any. Corresponds to the JSON property policyTags



3681
3682
3683
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3681

def policy_tags
  @policy_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3688
3689
3690
3691
3692
3693
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 3688

def update!(**args)
  @activated_policy_types = args[:activated_policy_types] if args.key?(:activated_policy_types)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @policy_tags = args[:policy_tags] if args.key?(:policy_tags)
end