Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1UsageStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb

Overview

Detailed counts on the entry's usage. Caveats: - Only BigQuery tables have usage stats - The usage stats only include BigQuery query jobs - The usage stats might be underestimated, e.g. wildcard table references are not yet counted in usage computation https://cloud.google.com/bigquery/docs/querying- wildcard-tables

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1UsageStats

Returns a new instance of GoogleCloudDatacatalogV1beta1UsageStats.



4141
4142
4143
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 4141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#total_cancellationsFloat

The number of times that the underlying entry was attempted to be used but was cancelled by the user. Corresponds to the JSON property totalCancellations

Returns:

  • (Float)


4123
4124
4125
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 4123

def total_cancellations
  @total_cancellations
end

#total_completionsFloat

The number of times that the underlying entry was successfully used. Corresponds to the JSON property totalCompletions

Returns:

  • (Float)


4128
4129
4130
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 4128

def total_completions
  @total_completions
end

#total_execution_time_for_completions_millisFloat

Total time spent (in milliseconds) during uses the resulted in completions. Corresponds to the JSON property totalExecutionTimeForCompletionsMillis

Returns:

  • (Float)


4133
4134
4135
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 4133

def total_execution_time_for_completions_millis
  @total_execution_time_for_completions_millis
end

#total_failuresFloat

The number of times that the underlying entry was attempted to be used but failed. Corresponds to the JSON property totalFailures

Returns:

  • (Float)


4139
4140
4141
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 4139

def total_failures
  @total_failures
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4146
4147
4148
4149
4150
4151
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 4146

def update!(**args)
  @total_cancellations = args[:total_cancellations] if args.key?(:total_cancellations)
  @total_completions = args[:total_completions] if args.key?(:total_completions)
  @total_execution_time_for_completions_millis = args[:total_execution_time_for_completions_millis] if args.key?(:total_execution_time_for_completions_millis)
  @total_failures = args[:total_failures] if args.key?(:total_failures)
end