Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexTableSpec
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexTableSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
Entry specification for a Dataplex Universal Catalog table.
Instance Attribute Summary collapse
-
#dataplex_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexSpec
Common Dataplex Universal Catalog fields.
-
#external_tables ⇒ Array<Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexExternalTable>
List of external tables registered by Dataplex Universal Catalog in other systems based on the same underlying data.
-
#user_managed ⇒ Boolean
(also: #user_managed?)
Indicates if the table schema is managed by the user or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexTableSpec
constructor
A new instance of GoogleCloudDatacatalogV1DataplexTableSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1DataplexTableSpec
Returns a new instance of GoogleCloudDatacatalogV1DataplexTableSpec.
938 939 940 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataplex_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexSpec
Common Dataplex Universal Catalog fields.
Corresponds to the JSON property dataplexSpec
923 924 925 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 923 def dataplex_spec @dataplex_spec end |
#external_tables ⇒ Array<Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1DataplexExternalTable>
List of external tables registered by Dataplex Universal Catalog in other
systems based on the same underlying data. External tables allow to query this
data in those systems.
Corresponds to the JSON property externalTables
930 931 932 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 930 def external_tables @external_tables end |
#user_managed ⇒ Boolean Also known as: user_managed?
Indicates if the table schema is managed by the user or not.
Corresponds to the JSON property userManaged
935 936 937 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 935 def user_managed @user_managed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
943 944 945 946 947 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 943 def update!(**args) @dataplex_spec = args[:dataplex_spec] if args.key?(:dataplex_spec) @external_tables = args[:external_tables] if args.key?(:external_tables) @user_managed = args[:user_managed] if args.key?(:user_managed) end |