Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTable
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
Element table definition.
Instance Attribute Summary collapse
-
#alias ⇒ String
Required.
-
#data_source ⇒ String
Required.
-
#destination_node_reference ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
A reference to a source or destination node in a graph edge.
-
#dynamic_label_column ⇒ String
Optional.
-
#dynamic_properties_column ⇒ String
Optional.
-
#element_keys ⇒ Array<String>
Required.
-
#input_source ⇒ String
Required.
-
#kind ⇒ String
Required.
-
#label_and_properties ⇒ Array<Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties>
Required.
-
#source_node_reference ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
A reference to a source or destination node in a graph edge.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1GraphSpecGraphElementTable
constructor
A new instance of GoogleCloudDatacatalogV1GraphSpecGraphElementTable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1GraphSpecGraphElementTable
Returns a new instance of GoogleCloudDatacatalogV1GraphSpecGraphElementTable.
1470 1471 1472 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alias ⇒ String
Required. The alias name of the graph element.
Corresponds to the JSON property alias
1419 1420 1421 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1419 def alias @alias end |
#data_source ⇒ String
Required. The name of the data source. This is either a table name or a view
name that is used for graph element input source. E.g. Person table or
PersonView view.
Corresponds to the JSON property dataSource
1426 1427 1428 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1426 def data_source @data_source end |
#destination_node_reference ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
A reference to a source or destination node in a graph edge.
Corresponds to the JSON property destinationNodeReference
1431 1432 1433 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1431 def destination_node_reference @destination_node_reference end |
#dynamic_label_column ⇒ String
Optional. If set, this is the input column for dynamic label in schemaless
data model.
Corresponds to the JSON property dynamicLabelColumn
1437 1438 1439 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1437 def dynamic_label_column @dynamic_label_column end |
#dynamic_properties_column ⇒ String
Optional. If set, this is the input column for dynamic properties in
schemaless data model.
Corresponds to the JSON property dynamicPropertiesColumn
1443 1444 1445 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1443 def dynamic_properties_column @dynamic_properties_column end |
#element_keys ⇒ Array<String>
Required. The name of the keys of the elements in the table.
Corresponds to the JSON property elementKeys
1448 1449 1450 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1448 def element_keys @element_keys end |
#input_source ⇒ String
Required. The input source of the graph element.
Corresponds to the JSON property inputSource
1453 1454 1455 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1453 def input_source @input_source end |
#kind ⇒ String
Required. The kind of the graph element.
Corresponds to the JSON property kind
1458 1459 1460 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1458 def kind @kind end |
#label_and_properties ⇒ Array<Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties>
Required. The labels and their properties for the graph element.
Corresponds to the JSON property labelAndProperties
1463 1464 1465 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1463 def label_and_properties @label_and_properties end |
#source_node_reference ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference
A reference to a source or destination node in a graph edge.
Corresponds to the JSON property sourceNodeReference
1468 1469 1470 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1468 def source_node_reference @source_node_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 1475 def update!(**args) @alias = args[:alias] if args.key?(:alias) @data_source = args[:data_source] if args.key?(:data_source) @destination_node_reference = args[:destination_node_reference] if args.key?(:destination_node_reference) @dynamic_label_column = args[:dynamic_label_column] if args.key?(:dynamic_label_column) @dynamic_properties_column = args[:dynamic_properties_column] if args.key?(:dynamic_properties_column) @element_keys = args[:element_keys] if args.key?(:element_keys) @input_source = args[:input_source] if args.key?(:input_source) @kind = args[:kind] if args.key?(:kind) @label_and_properties = args[:label_and_properties] if args.key?(:label_and_properties) @source_node_reference = args[:source_node_reference] if args.key?(:source_node_reference) end |