Class: Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1Entry
- Inherits:
-
Object
- Object
- Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1Entry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datacatalog_v1beta1/classes.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb,
lib/google/apis/datacatalog_v1beta1/representations.rb
Overview
Entry Metadata. A Data Catalog Entry resource represents another resource in
Google Cloud Platform (such as a BigQuery dataset or a Pub/Sub topic), or
outside of Google Cloud Platform. Clients can use the linked_resource field
in the Entry resource to refer to the original resource ID of the source
system. An Entry resource contains resource details, such as its schema. An
Entry can also be used to attach flexible metadata, such as a Tag.
Instance Attribute Summary collapse
-
#bigquery_date_sharded_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1BigQueryDateShardedSpec
Spec for a group of BigQuery tables with name pattern
[prefix]YYYYMMDD. -
#bigquery_table_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1BigQueryTableSpec
Describes a BigQuery table.
-
#description ⇒ String
Entry description, which can consist of several sentences or paragraphs that describe entry contents.
-
#display_name ⇒ String
Display information such as title and description.
-
#gcs_fileset_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1GcsFilesetSpec
Describes a Cloud Storage fileset entry.
-
#integrated_system ⇒ String
Output only.
-
#linked_resource ⇒ String
The resource this metadata entry refers to.
-
#name ⇒ String
Output only.
-
#schema ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1Schema
Represents a schema (e.g. BigQuery, GoogleSQL, Avro schema).
-
#source_system_timestamps ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SystemTimestamps
Timestamps about this resource according to a particular system.
-
#type ⇒ String
The type of the entry.
-
#usage_signal ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1UsageSignal
The set of all usage signals that we store in Data Catalog.
-
#user_specified_system ⇒ String
This field indicates the entry's source system that Data Catalog does not integrate with.
-
#user_specified_type ⇒ String
Entry type if it does not fit any of the input-allowed values listed in
EntryTypeenum above.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1Entry
constructor
A new instance of GoogleCloudDatacatalogV1beta1Entry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogV1beta1Entry
Returns a new instance of GoogleCloudDatacatalogV1beta1Entry.
2890 2891 2892 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_date_sharded_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1BigQueryDateShardedSpec
Spec for a group of BigQuery tables with name pattern [prefix]YYYYMMDD.
Context: https://cloud.google.com/bigquery/docs/partitioned-tables#
partitioning_versus_sharding
Corresponds to the JSON property bigqueryDateShardedSpec
2800 2801 2802 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2800 def bigquery_date_sharded_spec @bigquery_date_sharded_spec end |
#bigquery_table_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1BigQueryTableSpec
Describes a BigQuery table.
Corresponds to the JSON property bigqueryTableSpec
2805 2806 2807 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2805 def bigquery_table_spec @bigquery_table_spec end |
#description ⇒ String
Entry description, which can consist of several sentences or paragraphs that
describe entry contents. Default value is an empty string.
Corresponds to the JSON property description
2811 2812 2813 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2811 def description @description end |
#display_name ⇒ String
Display information such as title and description. A short name to identify
the entry, for example, "Analytics Data - Jan 2011". Default value is an empty
string.
Corresponds to the JSON property displayName
2818 2819 2820 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2818 def display_name @display_name end |
#gcs_fileset_spec ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1GcsFilesetSpec
Describes a Cloud Storage fileset entry.
Corresponds to the JSON property gcsFilesetSpec
2823 2824 2825 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2823 def gcs_fileset_spec @gcs_fileset_spec end |
#integrated_system ⇒ String
Output only. This field indicates the entry's source system that Data Catalog
integrates with, such as BigQuery or Pub/Sub.
Corresponds to the JSON property integratedSystem
2829 2830 2831 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2829 def integrated_system @integrated_system end |
#linked_resource ⇒ String
The resource this metadata entry refers to. For Google Cloud Platform
resources, linked_resource is the full name of the resource. For example, the
linked_resource for a table resource from BigQuery is: * //bigquery.
googleapis.com/projects/projectId/datasets/datasetId/tables/tableId Output
only when Entry is of type in the EntryType enum. For entries with
user_specified_type, this field is optional and defaults to an empty string.
Corresponds to the JSON property linkedResource
2840 2841 2842 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2840 def linked_resource @linked_resource end |
#name ⇒ String
Output only. Identifier. The Data Catalog resource name of the entry in URL
format. Example: * projects/project_id/locations/location/entryGroups/
entry_group_id/entries/entry_id Note that this Entry and its child
resources may not actually be stored in the location in this name.
Corresponds to the JSON property name
2848 2849 2850 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2848 def name @name end |
#schema ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1Schema
Represents a schema (e.g. BigQuery, GoogleSQL, Avro schema).
Corresponds to the JSON property schema
2853 2854 2855 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2853 def schema @schema end |
#source_system_timestamps ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1SystemTimestamps
Timestamps about this resource according to a particular system.
Corresponds to the JSON property sourceSystemTimestamps
2858 2859 2860 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2858 def @source_system_timestamps end |
#type ⇒ String
The type of the entry. Only used for Entries with types in the EntryType enum.
Corresponds to the JSON property type
2863 2864 2865 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2863 def type @type end |
#usage_signal ⇒ Google::Apis::DatacatalogV1beta1::GoogleCloudDatacatalogV1beta1UsageSignal
The set of all usage signals that we store in Data Catalog.
Corresponds to the JSON property usageSignal
2868 2869 2870 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2868 def usage_signal @usage_signal end |
#user_specified_system ⇒ String
This field indicates the entry's source system that Data Catalog does not
integrate with. user_specified_system strings must begin with a letter or
underscore and can only contain letters, numbers, and underscores; are case
insensitive; must be at least 1 character and at most 64 characters long.
Corresponds to the JSON property userSpecifiedSystem
2876 2877 2878 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2876 def user_specified_system @user_specified_system end |
#user_specified_type ⇒ String
Entry type if it does not fit any of the input-allowed values listed in
EntryType enum above. When creating an entry, users should check the enum
values first, if nothing matches the entry to be created, then provide a
custom value, for example "my_special_type". user_specified_type strings
must begin with a letter or underscore and can only contain letters, numbers,
and underscores; are case insensitive; must be at least 1 character and at
most 64 characters long. Currently, only FILESET enum value is allowed. All
other entries created through Data Catalog must use user_specified_type.
Corresponds to the JSON property userSpecifiedType
2888 2889 2890 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2888 def user_specified_type @user_specified_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 |
# File 'lib/google/apis/datacatalog_v1beta1/classes.rb', line 2895 def update!(**args) @bigquery_date_sharded_spec = args[:bigquery_date_sharded_spec] if args.key?(:bigquery_date_sharded_spec) @bigquery_table_spec = args[:bigquery_table_spec] if args.key?(:bigquery_table_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @gcs_fileset_spec = args[:gcs_fileset_spec] if args.key?(:gcs_fileset_spec) @integrated_system = args[:integrated_system] if args.key?(:integrated_system) @linked_resource = args[:linked_resource] if args.key?(:linked_resource) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) @source_system_timestamps = args[:source_system_timestamps] if args.key?(:source_system_timestamps) @type = args[:type] if args.key?(:type) @usage_signal = args[:usage_signal] if args.key?(:usage_signal) @user_specified_system = args[:user_specified_system] if args.key?(:user_specified_system) @user_specified_type = args[:user_specified_type] if args.key?(:user_specified_type) end |